DiversityCurve defines diversity (\(D\)) scores over multiple diversity
orders (\(Q\)).
# S4 method for DiversityCurve
print(x)# S4 method for DiversityCurve,missing
plot(x, y, ...)
DiversityCurve object
ignored.
arguments to pass to plotDiversityCurve.
datadata.frame defining the diversity curve with the following columns:
GROUP: group label.
Q: diversity order.
D: mean diversity index over all bootstrap
realizations.
D_SD: standard deviation of the diversity index
over all bootstrap realizations.
D_LOWER: diversity lower confidence inverval bound.
D_UPPER: diversity upper confidence interval bound.
E: evenness index calculated as D
divided by D at Q=0.
E_LOWER: evenness lower confidence inverval bound.
E_UPPER: eveness upper confidence interval bound.
groupscharacter vector of groups retained in the diversity calculation.
nnumeric vector indication the number of sequences sampled from each group.
nbootnumber of bootstrap realizations performed.
ciconfidence interval defining the upper and lower bounds (a value between 0 and 1).