Learn R Programming

alakazam (version 0.2.11)

DiversityTest-class: S4 class defining diversity significance

Description

DiversityTest defines the signifance of diversity (\(D\)) differences at a fixed diversity order (\(q\)).

Usage

# S4 method for DiversityTest
print(x)

# S4 method for DiversityTest,missing plot(x, y, ...)

Arguments

x

DiversityTest object.

y

ignored.

...

arguments to pass to plotDiversityTest.

Slots

tests

data.frame describing the significance test results with columns:

  • TEST: string listing the two groups tested.

  • DELTA_MEAN: mean of the \(D\) bootstrap delta distribution for the test.

  • DELTA_SD: standard deviation of the \(D\) bootstrap delta distribution for the test.

  • PVALUE: p-value for the test.

summary

data.frame containing summary statistics for the diversity index bootstrap distributions, at the given value of \(q\), with columns:

  • GROUP: the name of the group.

  • MEAN: mean of the \(D\) bootstrap distribution.

  • SD: standard deviation of the \(D\) bootstrap distribution.

groups

character vector of groups retained in diversity calculation.

q

diversity order tested (\(q\)).

n

numeric vector indication the number of sequences sampled from each group.

nboot

number of bootstrap realizations.