A translation list mapping IUPAC ambiguous characters code to corresponding nucleotide amino acid characters.
IUPAC_DNAIUPAC_AA
A list with single character codes as names and values containing character vectors that define the set of standard characters that match to each each ambiguous character.
IUPAC_DNA: DNA ambiguous character translations.
IUPAC_AA: Amino acid ambiguous character translations.