normalize
if TRUE then divide the aliphatic index of each amino acid
sequence by the number of informative positions. Non-informative
position are defined by the presence any character in
c("X", "-", ".", "*"). If FALSE then return the raw
aliphatic index.