Learn R Programming

alakazam (version 1.5.0)

fastDist: Faster calculation of pairwise distances between sequences of the same length and contain only "ACTGN?"

Description

fastDist calculates all pairwise distance between a set of sequences of the same length and contain only "ACTGN?". Input is case-insensitive; lowercase characters are converted to uppercase before comparison.

Usage

fastDist(seqs)

Value

Packed lower triangular matrix of distance between each entry in seq. If seq is a named vector, row and columns names will be added accordingly.

Arguments

seqs

character vector containing a DNA sequences.

Examples

Run this code
fastDist(c(A="ATGGC", B="ATGGG", C="ATGGG", D="AT?NC", E="NTGG?"))

Run the code above in your browser using DataLab