Learn R Programming

alakazam (version 1.5.0)

fastDistAA: Faster calculation of pairwise distances between amino acid sequences of the same length

Description

fastDistAA calculates all pairwise distances among a set of amino acid sequences of the same length. Amino acid sequences may contain the 20 standard amino acid characters and four special characters: (X, ., -, *). The characters X, -, and . match any character, whereas standard amino acids and stop codon * match only themselves.

Usage

fastDistAA(seqs)

Value

Packed lower triangular matrix of distance between each entry in seq. If seq is a named vector, row and columns names will be added accordingly.

Arguments

seqs

character vector containing an amino acid sequences.

Examples

Run this code
fastDistAA(c(A="AEHGC*X", B="AEHGGIC", C="AXGGGIC", D="ATTNC-E", E="N.TGG**"))

Run the code above in your browser using DataLab