powered by
getAAMatrix returns a Hamming distance matrix for IUPAC ambiguous amino acid characters.
getAAMatrix
getAAMatrix(gap = 0)
value to assign to characters in the set c("-", ".").
c("-", ".")
A matrix of amino acid character distances with row and column names indicating the character pair.
matrix
Creates an amino acid distance matrix for seqDist. See getDNAMatrix for nucleotide distances.
getAAMatrix()
Run the code above in your browser using DataLab