Learn R Programming

alakazam (version 1.5.0)

pairwiseEqual: Calculate pairwise equivalence between sequences

Description

pairwiseEqual determined pairwise equivalence between a pairs in a set of sequences, excluding ambiguous positions (Ns and gaps).

Usage

pairwiseEqual(seq, ignore = as.character(c("N", "-", ".", "?")))

Value

A logical matrix of equivalence between each entry in seq. Values are TRUE when sequences are equivalent and FALSE

when they are not.

Arguments

seq

character vector containing a DNA sequences.

ignore

vector of characters to ignore when testing for equality. Default is to ignore c("N","-",".","?")

See Also

Uses seqEqual for testing equivalence between pairs. See pairwiseDist for generating a sequence distance matrix.

Examples

Run this code
# Gaps and Ns will match any character
seq <- c(A="ATGGC", B="ATGGG", C="ATGGG", D="AT--C", E="NTGGG")
d <- pairwiseEqual(seq)
rownames(d) <- colnames(d) <- seq
d

# Ignore only Ns, so that gaps are not treated as matching any character
d <- pairwiseEqual(seq, ignore="N")
rownames(d) <- colnames(d) <- seq
d

Run the code above in your browser using DataLab