AbundanceCurve defines clonal abundance values.
# S4 method for AbundanceCurve
print(x)# S4 method for AbundanceCurve,missing
plot(x, y, ...)
AbundanceCurve object
ignored.
arguments to pass to plotDiversityCurve.
datadata.frame with relative clonal abundance data and confidence intervals, containing the following columns:
GROUP: group identifier.
CLONE: clone identifier.
P: relative abundance of the clone.
LOWER: lower confidence inverval bound.
UPPER: upper confidence interval bound.
RANK: the rank of the clone abundance.
groupscharacter vector of group values.
nnumeric vector indication the number of sequences in each group.
nbootnumber of bootstrap realizations performed.
ciconfidence interval defining the upper and lower bounds (a value between 0 and 1).