DiversityTest defines the signifance of diversity (\(D\)) differences at a
fixed diversity order (\(q\)).
# S4 method for DiversityTest
print(x)# S4 method for DiversityTest,missing
plot(x, y, ...)
DiversityTest object.
ignored.
arguments to pass to plotDiversityTest.
testsdata.frame describing the significance test results with columns:
TEST: string listing the two groups tested.
DELTA_MEAN: mean of the \(D\) bootstrap delta
distribution for the test.
DELTA_SD: standard deviation of the \(D\)
bootstrap delta distribution for the test.
PVALUE: p-value for the test.
summarydata.frame containing summary statistics for the diversity index bootstrap distributions, at the given value of \(q\), with columns:
GROUP: the name of the group.
MEAN: mean of the \(D\) bootstrap distribution.
SD: standard deviation of the \(D\) bootstrap
distribution.
groupscharacter vector of groups retained in diversity calculation.
qdiversity order tested (\(q\)).
nnumeric vector indication the number of sequences sampled from each group.
nbootnumber of bootstrap realizations.