Learn R Programming

alakazam (version 0.2.3)

DiversityTest-class: S4 class defining diversity significance

Description

DiversityTest defines the signifance of diversity ($D$) differences at a fixed diversity order ($q$).

Usage

"print"(x)

Arguments

x
DiversityTest object

Slots

tests
data.frame describing the significance test results with columns:
  • test: string listing the two groups tested.
  • pvalue: p-value for the test.
  • delta_mean: mean of the $D$ bootstrap delta distribution for the test.
  • delta_sd: standard deviation of the $D$ bootstrap delta distribution for the test.
summary
data.frame containing summary statistics for the diversity index bootstrap distributions, at the given value of $q$, with columns:
  • group: the name of the group.
  • mean: mean of the $D$ bootstrap distribution.
  • sd: standard deviation of the $D$ bootstrap distribution.
groups
character vector of groups retained in diversity calculation.
q
diversity order tested ($q$).
n
numeric vector indication the number of sequences sampled from each group.
nboot
number of bootstrap realizations.