Learn R Programming

alakazam (version 0.2.2)

alakazam: The alakazam package

Description

alakazam in a member of the Change-O suite of tools and serves three main purposes:
  • Providing core functionality for other R packages in the Change-O suite. This includes common tasks such as file I/O and basic DNA sequence manipulation.
  • Providing an R interface for interacting with the output of the pRESTO tool suite.
  • Providing tools to perform lineage reconstruction and diversity analysis on clonal populations of immunoglobulin (Ig) sequences.
For additional details regarding the use of the alakazam package see the vignettes: browseVignettes("alakazam")

Arguments

File I/O

Sequence cleaning

Lineage reconstruction

Diversity analysis

Ig and TCR sequence annotation

Sequence distance calculation

Amino acid propertes

General data manipulation

References

  1. Vander Heiden JA, Yaari G, et al. pRESTO: a toolkit for processing high-throughput sequencing raw reads of lymphocyte receptor repertoires. Bioinformatics. 2014 30(13):1930-2.
  2. Stern JNH, Yaari G, Vander Heiden JA, et al. B cells populating the multiple sclerosis brain mature in the draining cervical lymph nodes. Sci Transl Med. 2014 6(248):248ra107.
  3. Wu Y-CB, et al. Influence of seasonal exposure to grass pollen on local and peripheral blood IgE repertoires in patients with allergic rhinitis. J Allergy Clin Immunol. 2014 134(3):604-12.
  4. Gupta NT, Vander Heiden JA, et al. Change-O: a toolkit for analyzing large-scale B cell immunoglobulin repertoire sequencing data. Under review.