calcDiversity calculates the clonal diversity index for a vector of diversity
orders.
Usage
calcDiversity(p, q)
Arguments
p
numeric vector of clone (species) counts or proportions.
q
numeric vector of diversity orders.
Value
A vector of diversity scores $D$ for each $q$.
Details
This method, proposed by Hill (Hill, 1973), quantifies diversity as a smooth function
($D$) of a single parameter $q$. Special cases of the generalized diversity
index correspond to the most popular diversity measures in ecology: species richness
($q = 0$), the exponential of the Shannon-Weiner index ($q$ approaches $1$), the
inverse of the Simpson index ($q = 2$), and the reciprocal abundance of the largest
clone ($q$ approaches $+\infty$). At $q = 0$ different clones weight equally,
regardless of their size. As the parameter $q$ increase from $0$ to $+\infty$
the diversity index ($D$) depends less on rare clones and more on common (abundant)
ones, thus encompassing a range of definitions that can be visualized as a single curve.
Values of $q < 0$ are valid, but are generally not meaningful. The value of $D$
at $q=1$ is estimated by $D$ at $q=0.9999$.
References
Hill M. Diversity and evenness: a unifying notation and its consequences.
Ecology. 1973 54(2):427-32.