estimateAbundance estimates the complete clonal relative abundance distribution
and confidence intervals on clone sizes using bootstrapping.estimateAbundance(data, group, clone = "CLONE", copy = NULL, ci = 0.95,
nboot = 2000)data column containing group identifiers.data column containing clone identifiers.data column containing copy numbers for each
sequence. If copy=NULL (the default), then clone abundance
is determined by the number of sequences. If a copy column
is specified, then clone abundances is dGROUP: group identifier.CLONE: clone identifier.P: relative abundance of the clone.LOWER: lower confidence inverval bound.UPPER: upper confidence interval bound.RANK: the rank of the clone abundance.Confidence intervals are derived using the standard deviation of the resampling realizations, as described in Chao et al, 2015.
rarefyDiversity for a similar application to clonal diversity.# Load example data
file <- system.file("extdata", "ExampleDb.gz", package="alakazam")
df <- readChangeoDb(file)
abund <- estimateAbundance(df, "SAMPLE", nboot=100)Run the code above in your browser using DataLab