# Load example data
file <- system.file("extdata", "ExampleDb.gz", package="alakazam")
# Subset columns and convert sequence fields to upper case
df <- readChangeoDb(file, select=c("SEQUENCE_ID", "SEQUENCE_IMGT"), seq_upper=TRUE)
# Drop columns and do not alter sequence field case
df <- readChangeoDb(file, drop=c("D_CALL", "DUPCOUNT"), seq_upper=FALSE)Run the code above in your browser using DataLab